==> gameap-3.1-shared.zip: upload/resources/lang/ru/home.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Home page Language Lines
    |--------------------------------------------------------------------------
    |
    |
    */

    'main'              => 'Главное меню',
    'servers_list'      => 'Список серверов',

    'your_version'      => 'Ваша версия',
    'latest_stable'     => 'Последняя стабильная',
    'latest_beta'       => 'Последняя бета',
    'latest_unstable'   => 'Последняя нестабильная',

    'old_version'       => 'Ваша версия GameAP устарела',
    'actual_version'    => 'Вы используете актуальную версию GameAP',
    'dev_version'       => 'Вы используете DEV или неизвестную версию GameAP',

    'information'       => 'Информация',
    'problems'          => 'Проблемы',
    'get_help'          => 'Помощь',
    'documentation'     => 'Документация',
    'report_bug'        => 'Сообщить об ошибке',
    'update'            => 'Проверить обновления',

    'd_report_bug'      => 'Пожалуйста, проверьте версию PHP и наличи необходимых расширений PHP.
                        Версий PHP должна быть не ниже минимальной рекомендуемой.
                        Без необходимых расширений некоторые функции панели будут работать некорректно.',
    'send_report'       => 'Отправить отчет',
    'system_check'      => 'Проверка системы',

    'send_bug_success_msg' => 'Информация об ошибке успешно отправлена',

    'problems_list'     => [
        'required_extenstions_are_missed' => 'Отсутствуют необходимые расширения PHP: :extensions',
        'nodes_is_not_available'          => 'Недоступны некоторые выделенные серверы. Не удалось подключиться к следующим выделенным серверам: :nodes',
        'not_writable_directories'        => 'Следующие каталоги не имеют прав на запись: :paths',
    ]
];

==> gameap-3.2-shared.zip: upload/resources/lang/ru/home.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Home page Language Lines
    |--------------------------------------------------------------------------
    |
    |
    */

    'main'              => 'Главное меню',
    'servers_list'      => 'Список серверов',

    'your_version'      => 'Ваша версия',
    'latest_stable'     => 'Последняя стабильная',
    'latest_beta'       => 'Последняя бета',
    'latest_unstable'   => 'Последняя нестабильная',

    'old_version'       => 'Ваша версия GameAP устарела',
    'actual_version'    => 'Вы используете актуальную версию GameAP',
    'dev_version'       => 'Вы используете DEV или неизвестную версию GameAP',

    'information'       => 'Информация',
    'problems'          => 'Проблемы',
    'get_help'          => 'Помощь',
    'documentation'     => 'Документация',
    'api_documentation' => 'API Документация',
    'report_bug'        => 'Сообщить об ошибке',
    'update'            => 'Проверить обновления',
    'channels'          => 'Каналы',
    'support_gameap'    => 'Поддержать GameAP',
    'need_help'         => 'Нужна помощь?',

    'd_report_bug'      => 'Пожалуйста, проверьте версию PHP и наличи необходимых расширений PHP.
                        Версий PHP должна быть не ниже минимальной рекомендуемой.
                        Без необходимых расширений некоторые функции панели будут работать некорректно.',
    'send_report'       => 'Отправить отчет',
    'system_check'      => 'Проверка системы',

    'send_bug_success_msg' => 'Информация об ошибке успешно отправлена',

    'problems_list'     => [
        'required_extenstions_are_missed' => 'Отсутствуют необходимые расширения PHP: :extensions',
        'nodes_is_not_available'          => 'Недоступны некоторые выделенные серверы. Не удалось подключиться к следующим выделенным серверам: :nodes',
        'not_writable_directories'        => 'Следующие каталоги не имеют прав на запись: :paths',
    ]
];
